@@ -433,7 +433,7 @@ Start chatting (type 'HELP'/'h' for available commands, 'QUIT'/'q' to exit chat
                 break
 
         is_file_document = any(file_name_lower.endswith(ext)
-                               for ext in document_type_extensions)
+                                for ext in document_type_extensions)
 
         if is_file_document:
             return self.load_document_file(
@@ -532,7 +532,7 @@ Start chatting (type 'HELP'/'h' for available commands, 'QUIT'/'q' to exit chat
         return [x for x in glob.glob(text + '*')]
 
     def _retrieve_ara_config(self):
-        from ara_cli.prompt_handler import ConfigManager
+        from ara_cli.ara_config import ConfigManager
         return ConfigManager().get_config()
 
     def _retrieve_llm_config(self):
@@ -625,7 +625,7 @@ Start chatting (type 'HELP'/'h' for available commands, 'QUIT'/'q' to exit chat
     @cmd2.with_category(CATEGORY_LLM_CONTROL)
     def do_CHOOSE_MODEL(self, model_name):
         from ara_cli.prompt_handler import LLMSingleton
-        from ara_cli.ara_config import DEFAULT_CONFIG_LOCATION, save_data
+        from ara_cli.ara_config import DEFAULT_CONFIG_LOCATION, save_data, ConfigManager
         from ara_cli.directory_navigator import DirectoryNavigator
 
         original_dir = os.getcwd()
@@ -634,7 +634,11 @@ Start chatting (type 'HELP'/'h' for available commands, 'QUIT'/'q' to exit chat
         os.chdir('..')
 
         if not self._verify_llm_choice(model_name):
+            os.chdir(original_dir)
             return
+
+        ConfigManager.reset()
+        self.config = ConfigManager.get_config()
         self.config.default_llm = model_name
         save_data(filepath=DEFAULT_CONFIG_LOCATION, config=self.config)
 
@@ -643,10 +647,38 @@ Start chatting (type 'HELP'/'h' for available commands, 'QUIT'/'q' to exit chat
         os.chdir(original_dir)
 
     @cmd2.with_category(CATEGORY_LLM_CONTROL)
-    def do_CURRENT_MODEL(self, _):
-        from ara_cli.prompt_handler import LLMSingleton
+    def do_CHOOSE_EXTRACTION_MODEL(self, model_name):
+        """Choose the language model for extraction tasks."""
+        from ara_cli.ara_config import DEFAULT_CONFIG_LOCATION, save_data, ConfigManager
+        from ara_cli.directory_navigator import DirectoryNavigator
 
-        print(LLMSingleton.get_model())
+        original_dir = os.getcwd()
+        navigator = DirectoryNavigator()
+        navigator.navigate_to_target()
+        os.chdir('..')
+
+        if not self._verify_llm_choice(model_name):
+            os.chdir(original_dir)
+            return
+
+        ConfigManager.reset()
+        self.config = ConfigManager.get_config()
+        self.config.extraction_llm = model_name
+        save_data(filepath=DEFAULT_CONFIG_LOCATION, config=self.config)
+        print(f"Extraction model switched to '{model_name}'")
+
+        os.chdir(original_dir)
+
+    @cmd2.with_category(CATEGORY_LLM_CONTROL)
+    def do_CURRENT_MODEL(self, _):
+        """Displays the current default and extraction language models."""
+        from ara_cli.ara_config import ConfigManager
+
+        ConfigManager.reset()
+        config = self._retrieve_ara_config()
+        
+        print(f"Current Reasoning LLM (default_llm): {config.default_llm}")
+        print(f"Current Extraction LLM (extraction_llm): {config.extraction_llm}")
 
     def _complete_llms(self, text, line, begidx, endidx):
         llm_config = self._retrieve_llm_config()
@@ -662,6 +694,9 @@ Start chatting (type 'HELP'/'h' for available commands, 'QUIT'/'q' to exit chat
     def complete_CHOOSE_MODEL(self, text, line, begidx, endidx):
         return self._complete_llms(text, line, begidx, endidx)
 
+    def complete_CHOOSE_EXTRACTION_MODEL(self, text, line, begidx, endidx):
+        return self._complete_llms(text, line, begidx, endidx)
+
     @cmd2.with_category(CATEGORY_CHAT_CONTROL)
     def do_NEW(self, chat_name):
         """Create a new chat. Optionally provide a chat name in-line: NEW new_chat"""
@@ -859,3 +894,95 @@ Start chatting (type 'HELP'/'h' for available commands, 'QUIT'/'q' to exit chat
             completions = [classifier for classifier in classifiers if classifier.startswith(text)]
 
         return completions
+
+
+    def _get_plural_template_type(self, template_type: str) -> str:
+        """Determines the plural form of a template type."""
+        plurals = {"commands": "commands", "rules": "rules"}
+        return plurals.get(template_type, f"{template_type}s")
+
+    def _find_project_root(self) -> str | None:
+        """
+        Finds the project root by searching for an 'ara' directory,
+        starting from the chat file's directory and moving upwards.
+        """
+        current_dir = os.path.dirname(self.chat_name)
+        while True:
+            if os.path.isdir(os.path.join(current_dir, 'ara')):
+                return current_dir
+            parent_dir = os.path.dirname(current_dir)
+            if parent_dir == current_dir:  # Reached the filesystem root
+                return None
+            current_dir = parent_dir
+
+    def _gather_templates_from_path(self, search_path: str, templates_set: set, prefix: str = ""):
+        """
+        Scans a given path for items and adds them to the provided set,
+        optionally prepending a prefix.
+        """
+        import glob
+        if not os.path.isdir(search_path):
+            return
+        for path in glob.glob(os.path.join(search_path, '*')):
+            templates_set.add(f"{prefix}{os.path.basename(path)}")
+
+    def _get_available_templates(self, template_type: str) -> list[str]:
+        """
+        Scans for available global and project-local custom templates.
+        This method safely searches for template files without changing the
+        current directory, making it safe for use in autocompleters.
+
+        Args:
+            template_type: The type of template to search for (e.g., 'rules').
+
+        Returns:
+            A sorted list of unique template names. Global templates are
+            prefixed with 'global/'.
+        """
+        from ara_cli.template_manager import TemplatePathManager
+
+        plural_type = self._get_plural_template_type(template_type)
+        templates = set()
+
+        # 1. Find Global Templates
+        try:
+            global_base_path = TemplatePathManager.get_template_base_path()
+            global_template_dir = os.path.join(global_base_path, "prompt-modules", plural_type)
+            self._gather_templates_from_path(global_template_dir, templates, prefix="global/")
+        except Exception:
+            pass  # Silently ignore if global templates are not found
+
+        # 2. Find Local Custom Templates
+        try:
+            project_root = self._find_project_root()
+            if project_root:
+                local_templates_base = os.path.join(project_root, self.config.local_prompt_templates_dir)
+                custom_dir = os.path.join(local_templates_base, self.config.custom_prompt_templates_subdir, plural_type)
+                self._gather_templates_from_path(custom_dir, templates)
+        except Exception:
+            pass  # Silently ignore if local templates cannot be resolved
+
+        return sorted(list(templates))
+
+    def _template_completer(self, text: str, template_type: str) -> list[str]:
+        """Generic completer for different template types."""
+        available_templates = self._get_available_templates(template_type)
+        if not text:
+            return available_templates
+        return [t for t in available_templates if t.startswith(text)]
+
+    def complete_LOAD_RULES(self, text, line, begidx, endidx):
+        """Completer for the LOAD_RULES command."""
+        return self._template_completer(text, "rules")
+
+    def complete_LOAD_INTENTION(self, text, line, begidx, endidx):
+        """Completer for the LOAD_INTENTION command."""
+        return self._template_completer(text, "intention")
+
+    def complete_LOAD_COMMANDS(self, text, line, begidx, endidx):
+        """Completer for the LOAD_COMMANDS command."""
+        return self._template_completer(text, "commands")
+
+    def complete_LOAD_BLUEPRINT(self, text, line, begidx, endidx):
+        """Completer for the LOAD_BLUEPRINT command."""
+        return self._template_completer(text, "blueprint")
