@@ -28,3 +28,15 @@ class ParentNameCompleter:
         classifier = parsed_args.parent_classifier
 
         return find_classified_artefacts(prefix, classifier)
+
+
+class StatusCompleter:
+    def __call__(self, prefix, parsed_args, **kwargs):
+        status_tags = [
+            "to-do",
+            "in-progress",
+            "review",
+            "done",
+            "closed"
+        ]
+        return status_tags
