@@ -6,7 +6,7 @@ from contextlib import contextmanager
 @contextmanager
 def suppress_stdout(suppress=False):
     if suppress:
-        with open(os.devnull, "w") as devnull:
+        with open(os.devnull, "w", encoding="utf-8") as devnull:
             old_stdout = sys.stdout
             sys.stdout = devnull
             try:
@@ -14,4 +14,4 @@ def suppress_stdout(suppress=False):
             finally:
                 sys.stdout = old_stdout
     else:
-        yield
\ No newline at end of file
+        yield
