@@ -192,7 +192,7 @@ def handle_existing_file(filename, block_content, skip_query=False):
         messages = [{"role": "user", "content": prompt_text}]
         response = ""
 
-        for chunk in send_prompt(messages):
+        for chunk in send_prompt(messages, purpose='extraction'):
             content = chunk.choices[0].delta.content
             if content:
                 response += content
