@@ -71,29 +71,54 @@ def read_string_from_file(path):
         text = file.read()
     return text
 
+def _get_model_config(purpose: str) -> dict:
+    """
+    Resolves model ID by purpose and returns its prepared configuration for LiteLLM.
+    """
+    config = ConfigManager().get_config()
 
-def send_prompt(prompt):
-    chat = LLMSingleton.get_instance()
+    # Determine which model to use based on the purpose
+    model_id = config.default_llm
+    if purpose == 'extraction':
+        # Use extraction_llm if it exists, otherwise fall back to default_llm
+        model_id = getattr(config, 'extraction_llm', config.default_llm)
 
-    config_parameters = chat.config_parameters.copy()
-    if "provider" in config_parameters:
-        del config_parameters["provider"]
+    selected_config = config.llm_config.get(str(model_id))
 
-    filtered_prompt = list(filter(
-        lambda msg: (
-            msg.get('content') and
-            isinstance(msg['content'], list) and
-            any(
-                item.get('type') == 'text' and
-                item.get('text', '').strip() != ''
-                for item in msg['content']
-            )
-        ) or (
-            isinstance(msg.get('content'), str) and
-            msg['content'].strip() != ''
-        ),
-        prompt
-    ))
+    if not selected_config:
+        raise ValueError(f"No configuration found for model '{model_id}' used for '{purpose}'")
+
+    config_parameters = selected_config.model_dump(exclude_none=True)
+    config_parameters.pop("provider", None)
+    
+    return config_parameters
+
+
+def _is_valid_message(message: dict) -> bool:
+    """
+    Checks if a message in a prompt is valid (i.e., not empty).
+    It handles both string content and list content (for multimodal inputs).
+    """
+    content = message.get('content')
+
+    if isinstance(content, str):
+        return content.strip() != ''
+    
+    if isinstance(content, list):
+        # For multimodal content, check if there's at least one non-empty text part.
+        return any(
+            item.get('type') == 'text' and item.get('text', '').strip() != ''
+            for item in content
+        )
+        
+    return False
+
+
+def send_prompt(prompt, purpose='default'):
+    """Prepares and sends a prompt to the LLM, streaming the response."""
+    config_parameters = _get_model_config(purpose)
+
+    filtered_prompt = [msg for msg in prompt if _is_valid_message(msg)]
 
     completion = litellm.completion(
         **config_parameters,
