@@ -97,8 +97,8 @@ class TestARAconfig:
         config = ARAconfig()
         assert config.ext_code_dirs == [{"source_dir": "./src"}, {"source_dir": "./tests"}]
         assert config.glossary_dir == "./glossary"
-        assert config.default_llm == "gpt-4o"
-        assert "gpt-4o" in config.llm_config
+        assert config.default_llm == "gpt-5"
+        assert "gpt-5" in config.llm_config
 
     @patch('sys.stdout', new_callable=StringIO)
     def test_check_critical_fields_with_empty_list_reverts_to_default(self, mock_stdout):
@@ -228,7 +228,7 @@ class TestReadData:
         result = read_data("config.json")
         
         assert isinstance(result, ARAconfig)
-        assert result.default_llm == "gpt-4o"  # Should be the default config
+        assert result.default_llm == "gpt-5"  # Should be the default config
         
         output = mock_stdout.getvalue()
         assert "Error: Invalid JSON in configuration file" in output
